@@ -5,17 +5,50 @@ from django.shortcuts import get_object_or_404
 from django.utils.timezone import now
 from rest_framework import mixins, status, viewsets
 from rest_framework.response import Response
+from rest_framework.schemas.openapi import AutoSchema
+from rest_framework.schemas.utils import is_list_view
 from rest_framework.serializers import ValidationError
 
 from network.api import filters, pagination, serializers
 from network.api.perms import StationOwnerPermission
-from network.base.models import Observation, Station, Transmitter
+from network.base.models import Observation, Station
 from network.base.rating_tasks import rate_observation
 from network.base.tasks import sync_to_db
 from network.base.validators import NegativeElevationError, NoTleSetError, \
     ObservationOverlapError, SinglePassError
 
 
+class ViewSchema(AutoSchema):
+    """
+    AutoSchema override
+    """
+    def _get_operation_id(self, path, method):
+        """
+        Compute an operation ID from the view name.
+        """
+        method_name = getattr(self.view, 'action', method.lower())
+        if is_list_view(path, method, self.view):
+            action = 'list'
+        elif method_name not in self.method_mapping:
+            action = method_name
+        else:
+            action = self.method_mapping[method.lower()]
+
+        name = self.view.__class__.__name__
+        if name.endswith('APIView'):
+            name = name[:-7]
+        elif name.endswith('View'):
+            name = name[:-4]
+
+        if name.endswith(action.title()):
+            name = name[:-len(action)]
+
+        if action == 'list' and not name.endswith('s'):
+            name += 's'
+
+        return action + name
+
+
 class ObservationView(  # pylint: disable=R0901
         mixins.ListModelMixin, mixins.RetrieveModelMixin, mixins.UpdateModelMixin,
         mixins.CreateModelMixin, viewsets.GenericViewSet):
@@ -27,7 +60,7 @@ class ObservationView(  # pylint: disable=R0901
 
     def get_serializer_class(self):
         """Returns the right serializer depending on http method that is used"""
-        if self.request.method == 'POST':
+        if self.action == 'create':
             return serializers.NewObservationSerializer
         return serializers.ObservationSerializer
 
@@ -103,10 +136,12 @@ class StationView(  # pylint: disable=R0901
 class TransmitterView(  # pylint: disable=R0901
         mixins.ListModelMixin, mixins.RetrieveModelMixin, viewsets.GenericViewSet):
     """SatNOGS Network Transmitter API view class"""
-    queryset = Transmitter.objects.all().order_by('uuid')
+    queryset = Observation.objects.order_by().values('transmitter_uuid').distinct()
     serializer_class = serializers.TransmitterSerializer
+    lookup_field = 'transmitter_uuid'
     filterset_class = filters.TransmitterViewFilter
     pagination_class = pagination.LinkedHeaderPageNumberPagination
+    schema = ViewSchema()
 
 
 class JobView(viewsets.ReadOnlyModelViewSet):  # pylint: disable=R0901
@@ -115,10 +150,11 @@ class JobView(viewsets.ReadOnlyModelViewSet):  # pylint: disable=R0901
     serializer_class = serializers.JobSerializer
     filterset_class = filters.ObservationViewFilter
     filterset_fields = ('ground_station')
+    schema = ViewSchema()
 
     def get_queryset(self):
         """Returns queryset for Job API view"""
-        queryset = self.queryset.filter(start__gte=now()).prefetch_related('tle')
+        queryset = self.queryset.filter(start__gte=now())
         ground_station_id = self.request.query_params.get('ground_station', None)
         if ground_station_id and self.request.user.is_authenticated:
             ground_station = get_object_or_404(Station, id=ground_station_id)
